#

##

###

###

##

##

    	quests
    		@ moves

    	venue

    		[ ] organization

    			/mediphy_1
    				/mints
    				/treasures
    					/treasure.1
    						mediphy.py
    							mediphy = {
    								"names": []
    							}

    					/treasure.2
    						treasure.py

    					/treasure.3
    						treasure.py

    				/trends
    					/[ephemeral]
    						#
    						#	This is for equality checks of sends.
    						#
    						#

    					/@monetary
    						[mongo:DB] DB_mediphy_trends

    							#
    							#	db.items.createIndex ({ key1: 1, key2: 1 }, { unique: true })
    							#
    							#
    							[mongo:collection] collection_treasures [{
    								#
    								#	The domain can only have one "."
    								#
    								#
    								"domain": "",

    								"names": "",

    								"tags": [],
    								"cautions": [],

    								"versions": {
    									"1.0.0": bits_id
    								}
    							}]

    							[mongo:collection] bites
    							[mongo:collection] bites.files
    								# This one is auto created by GridFS

    				mediphy_essence.py
    					essence = {

    					}

    		essential plays

    			[@ mediphy_1] mediphy ventures on

    				#
    				#	[ ] start the reverse proxy
    				#
    				#			https://treasure.1.mediphy
    				#			https://treasure.2.mediphy
    				#			https://treasure.3.mediphy
    				#
    				#	[ ]
    				#
    				#

    			[@ mediphy_1] mediphy ventures off

    			[@ mediphy_1] mediphy treasures inventory

    			[@ mediphy_1] mediphy treasures save --name "treasure.1" --version 1.0.0
    				#
    				#	This doesn't delete the treasure.
    				#	To delete, just use "rm" or something.
    				#

    				#
    				#	* search for "treasure.1" in the "treasures"
    				#	* search for "treasure.py" in "treasure.1"
    				#	* import "treasure" from "treasure.py"
    				#

    				#
    				#	EQ check:
    				#		* send tar file to trends
    				#		* receive tar file from trends to temporary
    				#

    			[@ mediphy_1] mediphy treasures receive --name "treasure.1" --version 1.0.0

    			[@ mediphy_1] mediphy trends inventory

    			[@ mediphy_1] mediphy trends search --name "treasure"

    		migrations

    			[ ] export as "mongo_db_1:mongo_collection_1"
    				import as "mongo_db_2:mongo_collection_2"

    	ranked

    		[ ] mediphy on

    			This should turn on "mongo"
    			and "sanic"

    		[ ] https://mediphy

    				Don't have definition numbers.
    				Don't use slants for links.

    		[ ] crown.JSON {
    				"name": "",
    				"tags": []
    			}

    		[ ] save a backup of GridFS
    			[ ] trend archives

    		[ ] mongo replica set

    		[ ] mint to trends with reversibility check

    	save
    		[ ] locks
    			[ ]